package at.ac.uibk.gitsearch.domain;

import java.text.ParseException;
import java.util.regex.MatchResult;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * represents an exercise id.
 * Also provides some utility methods to parse and unparse exercise Ids
 * @author Michael Breu
 *
 */
public class ExerciseId {
	
	private String projectId; // should be numeric
	private String path; // a path with slashes (root slash omitted)

	public ExerciseId() {
		
	}
	
	public ExerciseId(String projectId, String path) {
		super();
		this.projectId = projectId;
		this.path = path;
	}

	/**
	 * @return the projectId
	 */
	public String getProjectId() {
		return projectId;
	}

	/**
	 * @return the path
	 */
	public String getPath() {
		return path;
	}
	
    protected final static Pattern ExerciseIdPattern = Pattern.compile("(\\d+)(:(.*))?");

    public String toString() {
    	if(path==null)
    		return projectId;
    	if (path.equals(""))
    		return projectId;
    	return projectId + ":" + path;
    }
    
    /**
     * parses the external representation of an ExerciseId.
     * @param externalRepresentation
     * @return
     * @throws ParseException
     */
    public static ExerciseId fromString(String externalRepresentation) throws ParseException {
    	final Matcher ma = ExerciseIdPattern.matcher(externalRepresentation);
		if(!ma.matches()) throw new ParseException("Cannot parse " + externalRepresentation, 0);
        final MatchResult matchResult = ma.toMatchResult();
        
        String projectId = matchResult.group(1);
        String path = matchResult.group(3);
        
        while (path!=null && path.startsWith("/")) {
        	path = path.substring(1);
        }
        
        return new ExerciseId(projectId, path);
        

    }

}
